<h1 align="center">
<img src="https://raw.githubusercontent.com/lucabaldini/baldaquin/refs/heads/main/docs/_static/baldaquin_logo_small_light.png" width="120">
</h1><br>

[![License: GPL v3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
![Tag](https://img.shields.io/github/v/tag/lucabaldini/baldaquin)
[![CI](https://github.com/lucabaldini/baldaquin/actions/workflows/ci.yml/badge.svg)](https://github.com/lucabaldini/baldaquin/actions/workflows/ci.yml)
[![Docs](https://github.com/lucabaldini/baldaquin/actions/workflows/docs.yml/badge.svg)](https://github.com/lucabaldini/baldaquin/actions/workflows/docs.yml)

baldaquin (or the BALd DAQ User INterface) is an attempt at a general-purpose, modular and reusable
data acquisition framework based on modern technologies. (And, before you get too excited, baldaquin
is just a stub, and chances are that it might never actually turn into something useful.)

Stay tuned!
